@@ -42,7 +42,7 @@ except:
     if running_on_tablet:
         log('Using GTK widgets, install "python2.5-hildon" for this to work properly.')
 
-about_name = 'Panucci'
+about_name = 'Panucci 0.2-4'
 about_text = _('Resuming audiobook and podcast player')
 about_authors = ['Thomas Perl', 'Nick (nikosapi)', 'Matthew Taylor']
 about_website = 'http://panucci.garage.maemo.org/'
